;; Generated package description from async.el  -*- no-byte-compile: t -*-
(define-package "async" "1.9.5.0.20220818.222308" "Asynchronous processing in Emacs" '((emacs "24.4")) :commit "a75d35214d06c6b64d26428ec930fd2a2786e2eb" :authors '(("John Wiegley" . "jwiegley@gmail.com")) :maintainer '("Thierry Volpiatto" . "thievol@posteo.net") :keywords '("async") :url "https://github.com/jwiegley/emacs-async")
